PAWpySeed: density_ft_elem Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
density_ft_elem Struct Reference

`#include <momentum.h>`

Collaboration diagram for density_ft_elem:
[legend]

## Public Attributes
int | num_densities
int | total_projs
density_ft_t * | densities

## Member Data Documentation

density_ft_t* density_ft_elem::densities

int density_ft_elem::num_densities

int density_ft_elem::total_projs

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/momentum.h